// Copyright 2006 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
package bcexchanger;

import javax.microedition.rms.RecordEnumeration;
import javax.microedition.rms.RecordStore;

/**
 * 
 * This class abstracts an RMS system for storing the uid of the
 * contact entry from the address book, selected by user as own entry.
 * 
 * @version 1.0 29.09.2005
 */
public class Storage {

  /**
   * Gets the stored uid
   * 
   * @return string containing uid of the the contact entry from the
   *         address book, selected by user as own entry or null if no
   *         contact is previously selected
   * @exception Exception -
   *              in case of errors occur
   */
  static public String getBCUID() throws Exception {
    String uid = null;
    RecordStore db = RecordStore.openRecordStore("uid", true);

    RecordEnumeration e = db.enumerateRecords(null, null, false);

    if (!e.hasNextElement()) {
      uid = null;
    } else {
      byte[] record = e.nextRecord();
      if (record == null) {
        uid = null;
      } else {
        uid = new String(record);
      }
    }
    db.closeRecordStore();

    return uid;
  }

  /**
   * Stores the uid
   * 
   * @param uid -
   *          string containing uid of the the contact entry from the
   *          address book, selected by user as own entry
   * @exception Exception -
   *              in case of errors occur
   */
  static public void setBCUID(String uid) throws Exception {
    RecordStore db = RecordStore.openRecordStore("uid", true);

    // delete all records
    if (db.getNumRecords() != 0) {
      db.closeRecordStore();
      RecordStore.deleteRecordStore("uid");
      db = RecordStore.openRecordStore("uid", true);
    }

    byte[] record = uid.getBytes();
    db.addRecord(record, 0, record.length);

    db.closeRecordStore();
  }

}
