// Copyright 2006 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
package bcexchanger.ui;

import java.io.IOException;

import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.TextBox;
import javax.microedition.lcdui.TextField;
import bcexchanger.*;
import bcexchanger.comm.ExchangerCommImpl;
import bcexchanger.comm.ServiceDiscoveryState;

/**
 * 
 * This class implements the main screen of the application. Using
 * this screen user can initiate an exchange of business cards, change
 * own business card and exit the application
 * 
 * The class is extending an example.BCExchanger.ui.Screen class
 * 
 * @version 1.0 29.09.2005
 * @see example.BCExchanger.ui.Screen Design patterns: State
 */
public class MainScreen extends Screen {

  private Command changeBCCommand;
  private Command exitCommand;
  private Command sendBCCommand;
  private TextBox textBox;
  
  private int typeOfOperation = ServiceDiscoveryState.PUT;

  /**
   * Constructor
   * 
   * @param _midlet -
   *          the parent class which keeps the current UI state
   */
  public MainScreen(BCExchangerMIDlet _midlet) 
  {
    super(_midlet);
    midlet.initComm(); // init happens only the first time MainScreen
                        // is created
    String text = "Business Card Exchanger allows you to define your own business card "
        + "and exhange it with business cards of other users in vicinity "
        + "running the same application. The exchange is done over Bluetooth "
        + "and free of charge.\n\n"
        + "Use 'Change own card' to choose own card from the address book.\n"
        + "Use 'Exchange card' to initate the search and exchange of the cards.\n\n"
        + "The application is always waiting for connections from remote devices.";
   
    textBox = new TextBox("Business Card Exchanger", text, 999, TextField.UNEDITABLE);

    changeBCCommand = new Command("Change own card", Command.ITEM, 1);
    exitCommand = new Command("Exit", Command.EXIT, 1);
    sendBCCommand = new Command("Exchange cards", Command.ITEM, 1);

    textBox.addCommand(changeBCCommand);
    textBox.addCommand(exitCommand);
    textBox.addCommand(sendBCCommand);
    textBox.setCommandListener(this);

    displayable = textBox;
  }

  public void commandAction(Command command, Displayable _displayable) {

    if (_displayable != textBox) {
      throw new RuntimeException("Internal error #16");
    }
    if (command == sendBCCommand) {
      try 
      {    	  
    	  setTypeOfOperation(ServiceDiscoveryState.PUT);
    	  ((ExchangerCommImpl)midlet.getExchanger()).startSending(ServiceDiscoveryState.PUT);
    	  String text = "Searching for devices...";
    	  midlet.changeScreen(new ProgressScreen(midlet, text));
      } 
      catch (IOException e0) {
        midlet.changeScreen(new AlertMessage(midlet,
            "Cannot start inquiry "+e0, null));
      } catch (Exception e1) {
      }
    } 
   
    else if (command == changeBCCommand) {

      midlet.changeScreen(new AddressBookScreen(midlet));
    } else if (command == exitCommand) {
      midlet.quit();
    } else {
      // unknown command
      throw new RuntimeException("Internal error #18");
    }
  }

  public int getTypeOfOperation() {
	return typeOfOperation;
  }

  public void setTypeOfOperation(int typeOfOperation) {
	this.typeOfOperation = typeOfOperation;
  }
}
